@@ -21,14 +21,15 @@
 #include "config.h"
 
 #include <string.h>
+
 #include <glib.h>
 
 #include <libxml/HTMLparser.h>
-#include <libtracker-common/tracker-statement-list.h>
 
-#include "tracker-main.h"
+#include <libtracker-common/tracker-ontologies.h>
 
-#include <libtracker-common/tracker-ontology.h>
+#include <libtracker-extract/tracker-extract.h>
+#include <libtracker-extract/tracker-utils.h>
 
 #define RDF_TYPE TRACKER_RDF_PREFIX "type"
 
@@ -43,6 +44,7 @@ typedef struct {
 } parser_data;
 
 static void extract_html (const gchar          *filename,
+                          TrackerSparqlBuilder *preupdate,
                           TrackerSparqlBuilder *metadata);
 
 static TrackerExtractData data[] = {
@@ -197,6 +199,7 @@ parser_characters (void          *data,
 
 static void
 extract_html (const gchar          *uri,
+              TrackerSparqlBuilder *preupdate,
               TrackerSparqlBuilder *metadata)
 {
 	htmlDocPtr doc;
@@ -237,7 +240,6 @@ extract_html (const gchar          *uri,
 		NULL  /* xmlStructuredErrorFunc */
 	};
 
-	tracker_sparql_builder_subject_iri (metadata, uri);
 	tracker_sparql_builder_predicate (metadata, "a");
 	tracker_sparql_builder_object (metadata, "nfo:Document");
 
@@ -255,7 +257,7 @@ extract_html (const gchar          *uri,
 }
 
 TrackerExtractData *
-tracker_get_extract_data (void)
+tracker_extract_get_data (void)
 {
 	return data;
 }
