@@ -26,14 +26,17 @@
 
 #include <string.h>
 #include <stdlib.h>
+
 #include <glib.h>
 #include <glib/gstdio.h>
 #include <gio/gio.h>
 
 #include <totem-pl-parser.h>
-#include <libtracker-common/tracker-ontology.h>
 
-#include "tracker-main.h"
+#include <libtracker-common/tracker-ontologies.h>
+
+#include <libtracker-extract/tracker-extract.h>
+#include <libtracker-extract/tracker-utils.h>
 
 #define PLAYLIST_PROPERTY_NO_TRACKS "entryCounter"
 #define PLAYLIST_PROPERTY_DURATION  "listDuration"
@@ -51,15 +54,15 @@
 #define RDF_TYPE RDF_PREFIX "type"
 
 typedef struct {
-	guint32     track_counter;
-	gint64      total_time;
-	TrackerSparqlBuilder   *metadata;
+	guint32 track_counter;
+	gint64 total_time;
+	TrackerSparqlBuilder *metadata;
 	const gchar *uri;
 } PlaylistMetadata;
 
-static void extract_playlist (const gchar *uri,
-                              TrackerSparqlBuilder   *metadata);
-
+static void extract_playlist (const gchar          *uri,
+                              TrackerSparqlBuilder *preupdate,
+                              TrackerSparqlBuilder *metadata);
 
 static TrackerExtractData playlist_data[] = {
 	{ "audio/x-mpegurl", extract_playlist },
@@ -124,8 +127,9 @@ entry_parsed (TotemPlParser *parser, const gchar *to_uri, GHashTable *to_metadat
 }
 
 static void
-extract_playlist (const gchar *uri,
-                  TrackerSparqlBuilder   *metadata)
+extract_playlist (const gchar          *uri,
+                  TrackerSparqlBuilder *preupdate,
+                  TrackerSparqlBuilder *metadata)
 {
 	TotemPlParser       *pl;
 	TotemPlParserResult  result;
@@ -138,7 +142,6 @@ extract_playlist (const gchar *uri,
 	g_signal_connect (G_OBJECT (pl), "entry-parsed",
 	                  G_CALLBACK (entry_parsed), &data);
 
-	tracker_sparql_builder_subject_iri (metadata, uri);
 	tracker_sparql_builder_predicate (metadata, "a");
 	tracker_sparql_builder_object (metadata, "nfo:MediaList");
 
@@ -174,7 +177,7 @@ extract_playlist (const gchar *uri,
 }
 
 TrackerExtractData *
-tracker_get_extract_data (void)
+tracker_extract_get_data (void)
 {
 	return playlist_data;
 }
