@@ -32,7 +32,7 @@
 #include <tiff.h>
 #include <tiffio.h>
 
-#include <libtracker-common/tracker-ontology.h>
+#include <libtracker-common/tracker-ontologies.h>
 #include <libtracker-common/tracker-type-utils.h>
 #include <libtracker-common/tracker-file-utils.h>
 #include <libtracker-common/tracker-utils.h>
@@ -41,6 +41,7 @@
 #include <libtracker-extract/tracker-xmp.h>
 #include <libtracker-extract/tracker-iptc.h>
 #include <libtracker-extract/tracker-exif.h>
+#include <libtracker-extract/tracker-utils.h>
 
 #define EXIF_DATE_FORMAT        "%Y:%m:%d %H:%M:%S"
 
@@ -307,10 +308,10 @@ extract_tiff (const gchar          *uri,
 	if (TIFFGetField (image, TIFFTAG_RICHTIFFIPTC, &iptcSize, &iptcOffset)) {
 		if (TIFFIsByteSwapped(image) != 0)
 			TIFFSwabArrayOfLong((uint32 *) iptcOffset, (unsigned long) iptcSize);
-		tracker_iptc_read (iptcOffset,
-		                   4 * iptcSize,
-		                   uri, 
-		                   &iptc_data);
+		tracker_extract_iptc_read (iptcOffset,
+		                           4 * iptcSize,
+		                           uri, 
+		                           &iptc_data);
 	}
 #endif /* HAVE_LIBIPTCDATA */
 
@@ -318,10 +319,10 @@ extract_tiff (const gchar          *uri,
 	   due to bugs in the original spec (type) */
 #ifdef HAVE_EXEMPI
 	if (TIFFGetField (image, TIFFTAG_XMLPACKET, &size, &xmpOffset)) {
-		tracker_xmp_read (xmpOffset,
-		                  size,
-		                  uri,
-		                  &xmp_data);
+		tracker_extract_xmp_read (xmpOffset,
+		                          size,
+		                          uri,
+		                          &xmp_data);
 	}
 #endif /* HAVE_EXEMPI */
 
@@ -333,8 +334,11 @@ extract_tiff (const gchar          *uri,
 		tiff_data.artist = get_value (image, TIFFTAG_ARTIST, TIFF_TAGTYPE_STRING);
 	if (!tiff_data.copyright)
 		tiff_data.copyright = get_value (image, TIFFTAG_COPYRIGHT, TIFF_TAGTYPE_STRING);
-	if (!tiff_data.datetime)
-		tiff_data.datetime = get_value (image, TIFFTAG_DATETIME, TIFF_TAGTYPE_STRING);
+	if (!tiff_data.datetime) {
+		gchar *date = get_value (image, TIFFTAG_DATETIME, TIFF_TAGTYPE_STRING);
+		tiff_data.datetime = tracker_extract_guess_date (date);
+		g_free (date);
+	}
 	if (!tiff_data.documentname)
 		tiff_data.documentname = get_value (image, TIFFTAG_DOCUMENTNAME, TIFF_TAGTYPE_STRING);
 	if (!tiff_data.imagedescription)
@@ -354,8 +358,11 @@ extract_tiff (const gchar          *uri,
 				exif_data.fnumber = get_value (image, EXIFTAG_FNUMBER, TIFF_TAGTYPE_DOUBLE);
 			if (!exif_data.iso_speed_ratings)
 				exif_data.iso_speed_ratings = get_value (image, EXIFTAG_ISOSPEEDRATINGS, TIFF_TAGTYPE_C16_UINT16);
-			if (!exif_data.time_original)
-				exif_data.time_original = get_value (image, EXIFTAG_DATETIMEORIGINAL, TIFF_TAGTYPE_STRING);
+			if (!exif_data.time_original) {
+				gchar *date = get_value (image, EXIFTAG_DATETIMEORIGINAL, TIFF_TAGTYPE_STRING);
+				exif_data.time_original = tracker_extract_guess_date (date);
+				g_free (date);
+			}
 			if (!exif_data.metering_mode)
 				exif_data.metering_mode = get_metering_mode (image);
 			if (!exif_data.flash)
