@@ -1,7 +1,5 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2006, Mr Jamie McCracken (jamiemcc@gnome.org)
- * Copyright (C) 2008, Nokia
+ * Copyright (C) 2010, Nokia
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -28,21 +26,10 @@
 
 G_BEGIN_DECLS
 
-typedef void (* TrackerDBusNameMonitorFunc) (const gchar *name,
-					     gboolean     available,
-					     gpointer     user_data);
-
-gboolean    tracker_dbus_init		   (void);
-void	    tracker_dbus_shutdown	   (void);
-gboolean    tracker_dbus_register_object   (GObject               *object,
-					    const DBusGObjectInfo *info,
-					    const gchar	          *path);
-
-void        tracker_dbus_add_name_monitor     (const gchar                *name,
-					       TrackerDBusNameMonitorFunc  func,
-					       gpointer                    user_data,
-					       GDestroyNotify              destroy_func);
-void        tracker_dbus_remove_name_monitor  (const gchar                *name);
+gboolean tracker_dbus_init             (void);
+void     tracker_dbus_shutdown         (void);
+gboolean tracker_dbus_register_objects (gpointer object);
+GObject *tracker_dbus_get_object       (GType    type);
 
 G_END_DECLS
 
