@@ -25,7 +25,7 @@
 #include <string.h>
 
 #include <libtracker-common/tracker-dbus.h>
-#include <libtracker-common/tracker-ontology.h>
+#include <libtracker-common/tracker-ontologies.h>
 
 #include <libtracker-db/tracker-db-dbus.h>
 
